@@ -11,7 +11,12 @@ Correlations = List[Tuple[int,str,Tuple[float]]]
 ResidueShifts = Dict[int, List[NamedTuple]]
 
 class Selector:
-    '''Defines selector for any correlations in constants.SIMPLE_ATOMS'''
+    '''Selector objects are used with a list of chemical shifts to select specific
+    correlations defined by `atoms'. This base class defines how correlations are
+    selected with its only public method `get_correlations'. Residues defines which
+    residues will be shown in the final spectrum. This class is used for any 
+    correlations in constants.SIMPLE_ATOMS.
+    '''
     def __init__(self, 
                 residues: List[str] = None,
                 atoms: Tuple[str] = None,
@@ -29,6 +34,7 @@ class Selector:
     def get_correlations(self, entity_shifts: List[NamedTuple]) -> Correlations:
         residue_shifts = self._get_residue_shifts(entity_shifts)
         shift_table = []
+        encountered_atoms = set()
         for seq_num, residue in residue_shifts.items():
             residue_type = residue[0].Comp_ID
             selections = self.selections.get(residue_type)
@@ -40,8 +46,12 @@ class Selector:
                         for atom in residue:
                             if atom.Atom_ID == spin:
                                 selected_atoms.append(float(atom.Val))
+                                encountered_atoms.add(atom.Atom_ID)
                     if len(selected_atoms) == len(self.atoms):
                         shift_table.append((seq_num, residue_type, tuple(selected_atoms)))
+        if not shift_table:
+            missing_atoms = set(self.atoms) - encountered_atoms
+            logging.error(f'Atom(s): {",".join(missing_atoms)} could not be found in assigned shifts.')
         return shift_table
     
     @staticmethod
@@ -88,6 +98,9 @@ class Selector:
                }
 
 class AmideSelector(Selector):
+    '''Subclass of Selector that returns H-N correlations, i.e. a 1H-15N HSQC.
+    Includes TRP indoles by default and can include sidechains on ASN and GLN if desired.
+    '''
     def __init__(self,
                 residues: List[str] = None, 
                 segment: Tuple[int] = None,
@@ -113,6 +126,9 @@ class AmideSelector(Selector):
         return residue_selections
 
 class MethylSelector(Selector):
+    '''Subclass of Selector that returns H - N correlations, i.e. a 1H-13C HMQC.
+    Allows proR and proS labeling to be simulated.
+    '''
     def __init__(self,
                 residues: List[str] = None,
                 segment: Tuple[int] = None,
@@ -127,7 +143,7 @@ class MethylSelector(Selector):
             non_milvat = set(self.residues) - constants.METHYL_ATOMS.keys()
             if non_milvat:
                 res_string = ','.join(sorted(non_milvat, key=self.residues.index))
-                logging.warn(f'residues other than MILVAT: ({res_string}) are ignored')
+                logging.warn(f'Residues other than MILVAT: ({res_string}) are ignored')
 
         self.residues = [residue 
                         for residue in constants.METHYL_ATOMS.keys()
@@ -149,6 +165,11 @@ class MethylSelector(Selector):
                }
 
 class AdvancedSelector(Selector):
+    '''Selector sublcass that allows for i+- correlations (i.e. H N CA-1) and handles
+    residues with branched chains or multiple atoms (usually protons) in the same position.
+    CMETHYL and HMETHYL can be used as atoms to select MILVAT methyl atoms or H# and C#
+    can be used to simulate TOCSY style experiments.
+    '''
     def __init__(self,
                 residues: List[str], 
                 atoms: Tuple[str],
@@ -214,6 +235,7 @@ class AdvancedSelector(Selector):
             # Group atoms by residue, each item is all assigned shifts for that residue
             residue_shifts = self._get_residue_shifts(entity_shifts)
             shift_table = []
+            encountered_atoms = set()
             
             # Filter out residues if sequence numbers for i+- cannot be found
             for ires in residue_shifts:
@@ -236,6 +258,7 @@ class AdvancedSelector(Selector):
                             for atom in residue:
                                 if atom.Atom_ID == correlation:
                                     selected_atoms.append((int(atom.Seq_ID), atom.Comp_ID, float(atom.Val)))
+                                    encountered_atoms.add(atom.Atom_ID)
                         group.append(selected_atoms)
 
                 # Reformat data and filter by those which have all atoms assigned
@@ -254,6 +277,10 @@ class AdvancedSelector(Selector):
                     except (IndexError, ValueError):
                         # not all atoms have assigned shifts or residue(s) filtered out
                         continue
+
+            if not shift_table:
+                missing_atoms = set(self.atoms) - encountered_atoms
+                logging.error(f'Atom(s): {",".join(missing_atoms)} could not be found in assigned shifts.')
             return shift_table
     
     def _get_plus_minus_atoms(self, atoms: str):
@@ -284,6 +311,9 @@ class AdvancedSelector(Selector):
         return tuple(plus_minus), tuple(split_atoms)
 
 class GroupSelector:
+    '''Selector-like object which handles atom groups i.e. H N (CA CA-1) and appends the
+    correlations, plotting them all on a single spectrum.
+    '''
     def __init__(self,
                 residues: List[str], 
                 atoms: Tuple[str],
